@@ -16,23 +16,21 @@ INSERT INTO agent_versions (dev_type, version_major, version_minor, version_patc
 (4, 1, 0, 1, true);
 
 INSERT INTO product_versions (id, actual, version_major, version_minor, version_patchlevel, version_string, major, beta, notification, force_display, release_date, description) values 
-(1, true, 1, 0, 3, 'Party patch3', false, false, true, true, '2025-06-06',
+(1, true, 1, 0, 5, 'Party patch5', false, true, true, true, NOW(),
 '<h5>Release notes</h5>'
 '<h6>Server:</h6><ul>'
-'<li>Catch and block invalid profile creation (e.g. when device provides invalid data).</li>'
-'<li>Immediately exit on extremely slow I/O containers where local DB connection cannot be established in 10 seconds. (instead of partial failure).</li>'
-'<li>Fix for Grafana integration with newer Grafana version.</li>'
+'<li>Updated bundled license.</li>'
 '</ul><h6>Agents:</h6><ul>'
 '</ul>');
 
-INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.3 (+2)');
+INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.4 (+3)');
 INSERT INTO product_flags(id, version, description) values ('about_info', 1, 'Dwarfguard - Monitoring, Alerting, Management and Automation System
 
-Build tag: v1.0.3 (+2)
-Build date: 2025_09_14__07_39_09
+Build tag: v1.0.4 (+3)
+Build date: 2025_09_15__11_26_01
 
 Build components:
-(mamas): v1.0.3 (+2)
-(mamasbig): v1.0.3
-(mamasweb): v1.0.3
-(mamasnotify): v1.0.3');
+(mamas): v1.0.4 (+2)
+(mamasbig): v1.0.4 (+1)
+(mamasweb): v1.0.4
+(mamasnotify): v1.0.4');
